@@ -14,8 +14,8 @@ const fs = require('fs-extra')
 const path = require('path')
 
 function prepareCheOperatorTemplates() {
-  const src = path.join(__dirname, 'node_modules', 'devspaces-operator', 'devspaces-operator', 'deploy', 'deployment', 'kubernetes', 'objects')
-  const templates = path.join(__dirname, 'templates', 'devspaces-operator', 'kubernetes')
+  const src = path.join(__dirname, 'node_modules', 'eclipse-che-operator', 'deploy', 'deployment', 'kubernetes', 'objects')
+  const templates = path.join(__dirname, 'templates', 'che-operator', 'kubernetes')
 
   fs.copySync(
     path.join(src, '..', 'org_v2_checluster.yaml'),
