@@ -13,7 +13,7 @@
 import { Octokit } from '@octokit/rest'
 
 export const ECLIPSE_CHE_INCUBATOR_ORG = 'che-incubator'
-export const CHECTL_REPO = 'dsc'
+export const CHECTL_REPO = 'chectl'
 
 export interface TagInfo {
   name: string
@@ -30,7 +30,7 @@ export class CheGithubClient {
   constructor() {
     this.octokit = new Octokit({
       baseUrl: 'https://api.github.com',
-      userAgent: 'dsc',
+      userAgent: 'chectl',
       auth: process.env.GITHUB_TOKEN,
     })
   }
