@@ -26,7 +26,7 @@ export const hook = async (options: { command: string, flags: any }) => {
     const configManager = ConfigManager.getInstance()
     let segmentTelemetry = configManager.getProperty(SegmentProperties.Telemetry)
 
-    // Prompt question if user allow dsc to collect data anonymous data.
+    // Prompt question if user allow chectl to collect data anonymous data.
     if (!options.flags.telemetry && !segmentTelemetry) {
       // Do not ask for enabling telemetry in batch mode. Just skip it if the telemetry flag is not set.
       if (options.flags.batch) {
@@ -38,7 +38,7 @@ export const hook = async (options: { command: string, flags: any }) => {
       configManager.setProperty(SegmentProperties.Telemetry, segmentTelemetry)
     }
 
-    // If not confirmed, dsc doesn't collect any data.
+    // If not confirmed, chectl doesn't collect any data.
     if (segmentTelemetry !== 'on') {
       return
     }
@@ -51,7 +51,7 @@ export const hook = async (options: { command: string, flags: any }) => {
 
     const segment = new SegmentAdapter({
       // tslint:disable-next-line:no-single-line-block-comment
-      segmentWriteKey: /* @mangle */'vNG9gWk3USWpKzIHDhMO25MwCRWSmjFn' /* @/mangle */,
+      segmentWriteKey: /* @mangle */'INSERT-KEY-HERE' /* @/mangle */,
     }, segmentId)
 
     await segment.identifySegmentEvent(segmentId)
