@@ -11,12 +11,12 @@
  */
 
 export namespace EclipseChe {
-  export const CHE_FLAVOR = 'devspaces'
-  export const PRODUCT_ID = 'devspaces'
-  export const PRODUCT_NAME = 'Red Hat OpenShift Dev Spaces'
+  export const CHE_FLAVOR = 'che'
+  export const PRODUCT_ID = 'eclipse-che'
+  export const PRODUCT_NAME = 'Eclipse Che'
 
   // Resources
-  export const NAMESPACE = 'openshift-devspaces'
+  export const NAMESPACE = 'eclipse-che'
   export const OPERATOR_SERVICE = `${CHE_FLAVOR}-operator-service`
   export const OPERATOR_SERVICE_CERT_SECRET = `${CHE_FLAVOR}-operator-service-cert`
   export const OPERATOR_SERVICE_ACCOUNT = `${CHE_FLAVOR}-operator`
@@ -39,12 +39,12 @@ export namespace EclipseChe {
   // OLM
   export const PACKAGE = PRODUCT_ID
   export const STABLE_CHANNEL = 'stable'
-  export const STABLE_CHANNEL_CATALOG_SOURCE = 'redhat-operators'
-  export const NEXT_CHANNEL = 'fast'
-  export const NEXT_CHANNEL_CATALOG_SOURCE = 'devspaces-fast'
+  export const STABLE_CHANNEL_CATALOG_SOURCE = 'community-operators'
+  export const NEXT_CHANNEL = 'next'
+  export const NEXT_CHANNEL_CATALOG_SOURCE = PRODUCT_ID
   export const NEXT_CATALOG_SOURCE_IMAGE = 'quay.io/eclipse/eclipse-che-olm-catalog:next'
-  export const SUBSCRIPTION = 'devspaces-subscription'
-  export const CSV_PREFIX = 'devspacesoperator'
+  export const SUBSCRIPTION = PRODUCT_ID
+  export const CSV_PREFIX = PRODUCT_ID
   export const APPROVAL_STRATEGY_MANUAL = 'Manual'
   export const APPROVAL_STRATEGY_AUTOMATIC = 'Automatic'
 
@@ -58,8 +58,8 @@ export namespace EclipseChe {
   export const OPERATOR_IMAGE_NEXT_TAG = 'next'
 
   // Doc links
-  export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.21/'
-  export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.21/html/release_notes_and_known_issues/index'
+  export const DOC_LINK = 'https://www.eclipse.org/che/docs/'
+  export const DOC_LINK_RELEASE_NOTES = ''
   export const DOC_LINK_CONFIGURE_API_SERVER = 'https://kubernetes.io/docs/reference/access-authn-authz/authentication/#configuring-the-api-server'
 
   // Components
