@@ -37,9 +37,9 @@ describe('Upgrade channel test', () => {
       ])
 
       await helper.waitForCheServerImageTag(helper.getNewVersion(), TIMEOUT_MS)
-      // uses installed dsc (from a stable channel)
+      // uses installed chectl (from a stable channel)
       // see github workflow
-      let deployCommand = `dsc server:deploy --batch --platform=${PLATFORM} --chenamespace=${NAMESPACE} --telemetry=off`
+      let deployCommand = `chectl server:deploy --batch --platform=${PLATFORM} --chenamespace=${NAMESPACE} --telemetry=off`
       if (PLATFORM === 'minikube') {
         deployCommand += ' --che-operator-cr-patch-yaml=test/e2e/resources/minikube-checluster-patch.yaml'
       }
